Skip to contents

Summarise interval changes in range summaries of Niche Boundary Exceedance

Usage

climniche_change_rate(
  x,
  metric = c("exposed_fraction", "range_wide_relative_exceedance",
    "mean_niche_boundary_exceedance"),
  scope = c("current", "all"),
  aggregation_weight = NULL,
  area_weight = FALSE,
  boundary_exceedance_tolerance = NULL
)

Arguments

x

A climniche_series object.

metric

Range summary used to quantify increase.

scope, aggregation_weight, area_weight, boundary_exceedance_tolerance

Arguments passed to climniche_range_summary().

Value

A data frame with one row per model and scenario.

Details

For a selected range summary \(X_t\), interval rates are $$g_k = \frac{X_{t_{k+1}} - X_{t_k}}{t_{k+1} - t_k}.$$ The function reports the largest positive \(g_k\) and its interval. Rates should only be compared among analyses using compatible temporal units and projection resolution.