Skip to contents

Build data for the climniche showcase figure

Usage

climniche_showcase_data(
  x,
  scope = c("current", "all"),
  max_points = 6000L,
  seed = 1L,
  plane_bins = 45L,
  boundary_probs = seq(0.5, 0.99, 0.01),
  top_variables = 6L
)

Arguments

x

A fitted climniche object.

scope

"current" for current occurrence, range or thresholded SDM cells; "all" for all evaluated cells.

max_points

Maximum number of cells to keep for the exposure plane.

seed

Random seed used when subsampling cells.

plane_bins

Number of fixed bins used to summarize the exposure plane.

boundary_probs

Boundary quantiles used for the sensitivity curve.

top_variables

Number of variables to show.

Value

A list of data frames used by plot_climniche_showcase().