Skip to contents

Build data for the climniche summary figure

Usage

climniche_summary_figure_data(
  x,
  scope = c("current", "all"),
  max_points = 6000L,
  seed = 1L,
  plane_bins = 35L,
  boundary_probs = seq(0.5, 0.99, 0.01),
  top_variables = 6L
)

Arguments

x

A fitted climniche object.

scope

"current" for current reference cells; "all" for all evaluated cells.

max_points

Maximum number of rows retained in the returned plane table. Figure bins are calculated from all cells in the selected scope.

seed

Random seed used when subsampling the returned plane table.

plane_bins

Number of fixed bins used to summarize the exposure plane.

boundary_probs

Boundary quantiles retained in the returned boundary table for downstream inspection.

top_variables

Number of variables to show.

Value

A list of data frames used by plot_climniche_summary_figure().