Skip to contents

Plot climniche classes

Usage

plot_climniche_classes(
  x,
  occupied = NULL,
  occupied_only = FALSE,
  occupied_threshold = 0,
  title = NULL
)

Arguments

x

A fitted climniche object with raster outputs.

occupied

Optional current occurrence/range RasterLayer to overlay.

occupied_only

If TRUE, mask the plotted classes to current occurrence cells.

occupied_threshold

Threshold used when occupied contains binary or continuous values.

title

Optional plot title. Use FALSE to suppress it.

Value

A ggplot object.