Plot the climniche showcase figure
Arguments
- x
A fitted climniche object or data returned by
climniche_showcase_data().- scope
"current"for current occurrence, range or thresholded SDM cells;"all"for all evaluated cells.- max_points
Maximum number of cells to draw in the exposure plane.
- seed
Random seed used when subsampling cells.
- plane_bins
Number of fixed bins used to summarize the exposure plane.
- boundary_probs
Boundary quantiles used for the sensitivity curve.
- top_variables
Number of variables to show.
- variable_labels
Optional named vector replacing variable labels.
- title
Optional overall title when
patchworkis installed.