Skip to contents

Plot range summaries of Niche Boundary Exceedance through time

Usage

plot_climniche_time(
  x,
  metric = c("range_wide_relative_exceedance", "exposed_fraction",
    "conditional_relative_exceedance", "mean_niche_boundary_exceedance"),
  scope = c("current", "all"),
  aggregation_weight = NULL,
  area_weight = FALSE,
  boundary_exceedance_tolerance = NULL,
  interval = 0.8,
  show_models = TRUE,
  title = NULL,
  base_size = 9
)

Arguments

x

A climniche_series object.

metric

Range summary field to display: exposed_fraction, conditional_relative_exceedance, range_wide_relative_exceedance or mean_niche_boundary_exceedance.

scope, aggregation_weight, area_weight, boundary_exceedance_tolerance

Arguments passed to climniche_range_summary().

interval

Central interval drawn across climate models.

show_models

If TRUE, draw individual climate model lines behind the ensemble median.

title

Optional plot title.

base_size

Base font size.

Value

A ggplot object.