Skip to contents

Simulate a minimal niche relative exposure example

Usage

simulate_climniche(
  n = 2000,
  p = 2,
  seed = 1,
  rho = 0,
  prevalence = 0.3,
  shift = 0.4
)

Arguments

n

Number of climate cells.

p

Number of climate variables.

seed

Random seed.

rho

Pairwise correlation among simulated climate variables.

prevalence

Proportion of background cells treated as true current occurrence locations under the virtual niche.

shift

Climatic Displacement imposed in the closer to niche and farther from niche scenarios.

Value

A list with current, future_toward, future_away, occupied, center, sensitivity and A.