Summarise agreement among projected climate models
Source:R/departure.R
climniche_model_agreement.RdSummarise agreement among projected climate models
Usage
climniche_model_agreement(
x,
scope = c("current", "all"),
boundary_exceedance_tolerance = NULL,
interval = 0.8
)Details
model_agreement is the proportion of supplied climate models with positive
Niche Boundary Exceedance. It is an ensemble agreement measure, not an
occurrence probability. Agreement is NA when fewer than two finite model
projections are available for a cell, time and scenario.
For \(M\) available models,
$$G_{it} = \frac{1}{M}\sum_{m=1}^{M} I(E_{imt} > \tau),$$
where \(\tau\) is boundary_exceedance_tolerance.