Build data for the climniche showcase figure
Arguments
- x
A fitted climniche object.
- scope
"current"for current occurrence, range or thresholded SDM cells;"all"for all evaluated cells.- max_points
Maximum number of cells to keep for the exposure plane.
- seed
Random seed used when subsampling cells.
- plane_bins
Number of fixed bins used to summarize the exposure plane.
- boundary_probs
Boundary quantiles used for the sensitivity curve.
- top_variables
Number of variables to show.
Value
A list of data frames used by plot_climniche_showcase().