Fit niche climate exposure
Usage
fit_climniche(
current,
future,
occupied = NULL,
occupied_threshold = 0,
cnfa = NULL,
center = NULL,
sensitivity = NULL,
A = NULL,
metric = c("diag", "factor"),
boundary = 0.95,
scale = TRUE,
global_mean = NULL,
global_sd = NULL,
conflict_ratio = 0.25
)Arguments
- current
Numeric matrix or data frame of current environmental values.
- future
Numeric matrix or data frame of future environmental values.
- occupied
NULL, logical vector, row indices, or a numeric vector with one value per row identifying current occurrence, range, or thresholded SDM cells.
- occupied_threshold
Threshold used when
occupiedcontains binary or continuous values.- cnfa
Optional CENFA model object.
- center
Optional realised niche centre in standardised climate space.
- sensitivity
Optional environmental sensitivity weights.
- A
Optional niche metric matrix.
- metric
Metric construction when
Ais not supplied.- boundary
Quantile defining the empirical realised niche boundary.
- scale
Logical. If TRUE, standardise current and future values.
- global_mean
Optional means used for standardisation.
- global_sd
Optional standard deviations used for standardisation.
- conflict_ratio
Minimum minority sign contribution share used to mark mixed variable responses. Set to NULL to disable this flag.