Skip to contents

Fit climniche to raster data

Usage

fit_climniche_raster(
  current,
  future,
  occupied = NULL,
  occupied_threshold = 0,
  domain = NULL,
  domain_threshold = 0,
  ...
)

Arguments

current

Raster* object of current environmental layers.

future

Raster* object of future environmental layers.

occupied

Optional RasterLayer with binary or continuous occurrence, range, or SDM suitability values.

occupied_threshold

Values greater than this threshold are treated as current occurrence cells.

domain

Optional RasterLayer limiting cells where exposure is analysed.

domain_threshold

Values greater than this threshold define the domain.

...

Additional arguments passed to fit_climniche().

Value

An object of class climniche_fit with raster outputs.