Fit climniche to terra raster data
Usage
fit_climniche_terra(
current,
future,
occupied = NULL,
occupied_threshold = 0,
domain = NULL,
domain_threshold = 0,
...
)Arguments
- current
terra SpatRaster of current environmental layers.
- future
terra SpatRaster of future environmental layers.
- occupied
Optional one layer SpatRaster with binary or continuous occurrence, range, or SDM suitability values.
- occupied_threshold
Values greater than this threshold are treated as current occurrence cells.
- domain
Optional one layer SpatRaster limiting cells where exposure is analysed.
- domain_threshold
Values greater than this threshold define the domain.
- ...
Additional arguments passed to
fit_climniche().