Map Niche Boundary Exceedance through time
Usage
plot_climniche_departure_map(
x,
metric = c("first_boundary_exceedance", "boundary_exceedance_projection_fraction",
"first_persistent_departure", "boundary_exceedance_time_fraction",
"departure_time_fraction", "mean_relative_exceedance", "maximum_relative_exceedance",
"model_agreement"),
model = NULL,
scenario = NULL,
time = NULL,
scope = c("current", "all"),
persistence = 1L,
boundary_exceedance_tolerance = NULL,
title = NULL,
legend_title = FALSE,
limits = NULL,
colours = NULL,
...
)Arguments
- x
A spatial
climniche_seriesobject.- metric
Temporal result field to map. Available fields include first sampled boundary exceedance (
first_boundary_exceedance), the fraction of projections beyond the boundary (boundary_exceedance_projection_fraction), persistent exceedance onset, interval-weighted exceedance, relative exceedance and climate model agreement.- model, scenario, time
Optional projection selectors. A selector is required when more than one relevant value is present.
- scope, persistence, boundary_exceedance_tolerance
Arguments passed to
climniche_departure()orclimniche_model_agreement().- title
Optional map title. Use
FALSEto suppress it.- legend_title
Optional legend title. The default suppresses a title that would repeat the map title.
- limits, colours
Optional colour-scale limits and colours.
- ...
Additional arguments passed to
plot_climniche_map().