Skip to contents

Plot a climniche map

Usage

plot_climniche_map(
  x,
  metric = c("niche_distance_change", "outside_niche_exceedance",
    "climate_change_amount", "composition_change", "change_alignment"),
  occupied = NULL,
  occupied_only = FALSE,
  occupied_threshold = 0,
  title = NULL,
  midpoint = 0
)

Arguments

x

A fitted climniche object with raster outputs, or a RasterLayer.

metric

Metric to plot.

occupied

Optional current occurrence/range RasterLayer to overlay.

occupied_only

If TRUE, mask the plotted raster to current occurrence cells.

occupied_threshold

Threshold used when occupied contains binary or continuous values.

title

Optional plot title. Use FALSE to suppress it.

midpoint

Midpoint for the niche distance change colour scale.

Value

A ggplot object.