Plot the climniche summary figure
Arguments
- x
A fitted climniche object or data returned by
climniche_summary_figure_data().- scope
"current"for current reference cells;"all"for all evaluated cells.- max_points
Maximum number of rows retained in the auxiliary
planetable. Figure bins use all cells in the selected scope.- seed
Random seed used when subsampling the auxiliary
planetable.- plane_bins
Number of fixed bins used to summarize the exposure plane.
- boundary_probs
Boundary quantiles retained in the auxiliary figure data.
- top_variables
Number of variables to show.
- variable_labels
Optional named vector replacing variable labels.
- title
Optional overall title when
patchworkis installed.